@@ -21,13 +21,16 @@
  */
 
 #include "basewrapper.h"
-#include <cstddef>
-#include <fstream>
 #include "basewrapper_p.h"
 #include "bindingmanager.h"
 #include "google/dense_hash_map"
 #include "sbkdbg.h"
 #include "gilstate.h"
+#include "sbkstring.h"
+
+#include <cstddef>
+#include <fstream>
+
 
 namespace Shiboken
 {
@@ -71,7 +74,7 @@ public:
     }
 #endif
 
-    SbkObjectType* identifyType(void* cptr, SbkObjectType* type, SbkObjectType* baseType) const
+    SbkObjectType* identifyType(void** cptr, SbkObjectType* type, SbkObjectType* baseType) const
     {
         Edges::const_iterator edgesIt = m_edges.find(type);
         if (edgesIt != m_edges.end()) {
@@ -83,7 +86,17 @@ public:
                     return newType;
             }
         }
-        return ((type->d && type->d->type_discovery) ? type->d->type_discovery(cptr, baseType) : 0);
+        void* typeFound = ((type->d && type->d->type_discovery) ? type->d->type_discovery(*cptr, baseType) : 0);
+        if (typeFound) {
+            // This "typeFound != type" is needed for backwards compatibility with old modules using a newer version of
+            // libshiboken because old versions of type_discovery function used to return a SbkObjectType* instead of
+            // a possible variation of the C++ instance pointer (*cptr).
+            if (typeFound != type)
+                *cptr = typeFound;
+            return type;
+        } else {
+            return 0;
+        }
     }
 };
 
@@ -98,8 +111,8 @@ static void showWrapperMap(const WrapperMap& wrapperMap)
         for (iter = wrapperMap.begin(); iter != wrapperMap.end(); ++iter) {
             fprintf(stderr, "key: %p, value: %p (%s, refcnt: %d)\n", iter->first,
                                                             iter->second,
-                                                            iter->second->ob_type->tp_name,
-                                                            (int) iter->second->ob_refcnt);
+                                                            Py_TYPE(iter->second)->tp_name,
+                                                            (int) ((PyObject*)iter->second)->ob_refcnt);
         }
         fprintf(stderr, "-------------------------------\n");
     }
@@ -166,7 +179,7 @@ bool BindingManager::hasWrapper(const void* cptr)
 
 void BindingManager::registerWrapper(SbkObject* pyObj, void* cptr)
 {
-    SbkObjectType* instanceType = reinterpret_cast<SbkObjectType*>(pyObj->ob_type);
+    SbkObjectType* instanceType = reinterpret_cast<SbkObjectType*>(Py_TYPE(pyObj));
     SbkObjectTypePrivate* d = instanceType->d;
 
     if (!d)
@@ -187,9 +200,9 @@ void BindingManager::registerWrapper(SbkObject* pyObj, void* cptr)
 
 void BindingManager::releaseWrapper(SbkObject* sbkObj)
 {
-    SbkObjectType* sbkType = reinterpret_cast<SbkObjectType*>(sbkObj->ob_type);
+    SbkObjectType* sbkType = reinterpret_cast<SbkObjectType*>(Py_TYPE(sbkObj));
     SbkObjectTypePrivate* d = sbkType->d;
-    int numBases = ((d && d->is_multicpp) ? getNumberOfCppBaseClasses(sbkObj->ob_type) : 1);
+    int numBases = ((d && d->is_multicpp) ? getNumberOfCppBaseClasses(Py_TYPE(sbkObj)) : 1);
 
     void** cptrs = reinterpret_cast<SbkObject*>(sbkObj)->d->cptr;
     for (int i = 0; i < numBases; ++i) {
@@ -231,13 +244,13 @@ PyObject* BindingManager::getOverride(const void* cptr, const char* methodName)
         }
     }
 
-    PyObject* pyMethodName = PyString_FromString(methodName);
+    PyObject* pyMethodName = Shiboken::String::fromCString(methodName);
     PyObject* method = PyObject_GetAttr((PyObject*)wrapper, pyMethodName);
 
     if (method && PyMethod_Check(method)
         && reinterpret_cast<PyMethodObject*>(method)->im_self == reinterpret_cast<PyObject*>(wrapper)) {
         PyObject* defaultMethod;
-        PyObject* mro = wrapper->ob_type->tp_mro;
+        PyObject* mro = Py_TYPE(wrapper)->tp_mro;
 
         // The first class in the mro (index 0) is the class being checked and it should not be tested.
         // The last class in the mro (size - 1) is the base Python object class which should not be tested also.
@@ -264,18 +277,23 @@ void BindingManager::addClassInheritance(SbkObjectType* parent, SbkObjectType* c
 }
 
 SbkObjectType* BindingManager::resolveType(void* cptr, SbkObjectType* type)
+{
+    return resolveType(&cptr, type);
+}
+
+SbkObjectType* BindingManager::resolveType(void** cptr, SbkObjectType* type)
 {
     SbkObjectType* identifiedType = m_d->classHierarchy.identifyType(cptr, type, type);
     return identifiedType ? identifiedType : type;
 }
 
-std::set<SbkObject*> BindingManager::getAllPyObjects()
+std::set<PyObject*> BindingManager::getAllPyObjects()
 {
-    std::set<SbkObject*> pyObjects;
+    std::set<PyObject*> pyObjects;
     const WrapperMap& wrappersMap = m_d->wrapperMapper;
     WrapperMap::const_iterator it = wrappersMap.begin();
     for (; it != wrappersMap.end(); ++it)
-        pyObjects.insert(it->second);
+        pyObjects.insert(reinterpret_cast<PyObject*>(it->second));
 
     return pyObjects;
 }
