@@ -24,7 +24,7 @@
 #define GILSTATE_H
 
 #include <shibokenmacros.h>
-#include <Python.h>
+#include "sbkpython.h"
 
 namespace Shiboken
 {
@@ -34,8 +34,10 @@ class LIBSHIBOKEN_API GilState
 public:
     GilState();
     ~GilState();
+    void release();
 private:
     PyGILState_STATE m_gstate;
+    bool m_locked;
 };
 
 } // namespace Shiboken
