@@ -22,21 +22,30 @@
 
 #include "sbkenum.h"
 #include "sbkstring.h"
+#include "sbkconverter.h"
 #include "basewrapper.h"
 #include "sbkdbg.h"
 #include "autodecref.h"
 #include "typeresolver.h"
+#include "sbkpython.h"
 
 #include <string.h>
 #include <cstring>
 #include <list>
 
-
-#define SBK_ENUM(ENUM)  reinterpret_cast<SbkEnumObject*>(ENUM)
+#define SBK_ENUM(ENUM) reinterpret_cast<SbkEnumObject*>(ENUM)
 
 extern "C"
 {
 
+struct SbkEnumType
+{
+    PyHeapTypeObject super;
+    SbkConverter** converterPtr;
+    SbkConverter* converter;
+    const char* cppName;
+};
+
 struct SbkEnumObject
 {
     PyObject_HEAD
@@ -91,13 +100,17 @@ static PyObject* SbkEnum_tp_new(PyTypeObject* type, PyObject* args, PyObject* kw
     return reinterpret_cast<PyObject*>(self);
 }
 
+/* Notes:
+ *   On Py3k land we use long type when using integer numbers. However, on older
+ *   versions of Python (version 2) we need to convert it to int type,
+ *   respectively.
+ *
+ *   Thus calling PyInt_FromLong() will result in calling PyLong_FromLong in
+ *   Py3k.
+ */
 static PyObject* enum_int(PyObject* v)
 {
-#ifdef IS_PY3K
-    return PyLong_FromLong(SBK_ENUM(v)->ob_value);
-#else
     return PyInt_FromLong(SBK_ENUM(v)->ob_value);
-#endif
 }
 
 static long getNumberValue(PyObject* v)
@@ -108,7 +121,6 @@ static long getNumberValue(PyObject* v)
     return result;
 }
 
-
 static PyObject* enum_and(PyObject* self, PyObject* b)
 {
     if (!PyNumber_Check(b)) {
@@ -118,7 +130,7 @@ static PyObject* enum_and(PyObject* self, PyObject* b)
 
     long valA = SBK_ENUM(self)->ob_value;
     long valB = getNumberValue(b);
-    return PyLong_FromLong(valA & valB);
+    return PyInt_FromLong(valA & valB);
 }
 
 static PyObject* enum_or(PyObject* self, PyObject* b)
@@ -130,7 +142,7 @@ static PyObject* enum_or(PyObject* self, PyObject* b)
 
     long valA = SBK_ENUM(self)->ob_value;
     long valB = getNumberValue(b);
-    return PyLong_FromLong(valA | valB);
+    return PyInt_FromLong(valA | valB);
 }
 
 static PyObject* enum_xor(PyObject* self, PyObject* b)
@@ -142,10 +154,9 @@ static PyObject* enum_xor(PyObject* self, PyObject* b)
 
     long valA = SBK_ENUM(self)->ob_value;
     long valB = getNumberValue(b);
-    return PyLong_FromLong(valA ^ valB);
+    return PyInt_FromLong(valA ^ valB);
 }
 
-
 static int enum_bool(PyObject* v)
 {
     return (SBK_ENUM(v)->ob_value > 0);
@@ -155,21 +166,21 @@ static PyObject* enum_add(PyObject* self, PyObject* v)
 {
     long valA = SBK_ENUM(self)->ob_value;
     long valB = getNumberValue(v);
-    return PyLong_FromLong(valA + valB);
+    return PyInt_FromLong(valA + valB);
 }
 
 static PyObject* enum_subtract(PyObject* self, PyObject* v)
 {
     long valA = SBK_ENUM(self)->ob_value;
     long valB = getNumberValue(v);
-    return PyLong_FromLong(valA - valB);
+    return PyInt_FromLong(valA - valB);
 }
 
 static PyObject* enum_multiply(PyObject* self, PyObject* v)
 {
     long valA = SBK_ENUM(self)->ob_value;
     long valB = getNumberValue(v);
-    return PyLong_FromLong(valA * valB);
+    return PyInt_FromLong(valA * valB);
 }
 
 #ifndef IS_PY3K
@@ -290,12 +301,15 @@ static PyNumberMethods enum_as_number = {
      /* nb_index */                 enum_int
 };
 
+static void SbkEnumTypeDealloc(PyObject* pyObj);
+static PyObject* SbkEnumTypeTpNew(PyTypeObject* metatype, PyObject* args, PyObject* kwds);
+
 PyTypeObject SbkEnumType_Type = {
     PyVarObject_HEAD_INIT(0, 0)
     /*tp_name*/             "Shiboken.EnumType",
-    /*tp_basicsize*/        sizeof(PyTypeObject),
+    /*tp_basicsize*/        sizeof(SbkEnumType),
     /*tp_itemsize*/         0,
-    /*tp_dealloc*/          0,
+    /*tp_dealloc*/          SbkEnumTypeDealloc,
     /*tp_print*/            0,
     /*tp_getattr*/          0,
     /*tp_setattr*/          0,
@@ -327,9 +341,9 @@ PyTypeObject SbkEnumType_Type = {
     /*tp_descr_set*/        0,
     /*tp_dictoffset*/       0,
     /*tp_init*/             0,
-    /*tp_alloc*/            0,
-    /*tp_new*/              PyType_GenericNew,
-    /*tp_free*/             0,
+    /*tp_alloc*/            PyType_GenericAlloc,
+    /*tp_new*/              SbkEnumTypeTpNew,
+    /*tp_free*/             PyObject_GC_Del,
     /*tp_is_gc*/            0,
     /*tp_bases*/            0,
     /*tp_mro*/              0,
@@ -338,6 +352,26 @@ PyTypeObject SbkEnumType_Type = {
     /*tp_weaklist*/         0
 };
 
+void SbkEnumTypeDealloc(PyObject* pyObj)
+{
+    SbkEnumType* sbkType = reinterpret_cast<SbkEnumType*>(pyObj);
+
+    PyObject_GC_UnTrack(pyObj);
+    Py_TRASHCAN_SAFE_BEGIN(pyObj);
+    if (sbkType->converter) {
+        Shiboken::Conversions::deleteConverter(sbkType->converter);
+    }
+    Py_TRASHCAN_SAFE_END(pyObj);
+}
+
+PyObject* SbkEnumTypeTpNew(PyTypeObject* metatype, PyObject* args, PyObject* kwds)
+{
+    SbkEnumType* newType = reinterpret_cast<SbkEnumType*>(PyType_Type.tp_new(metatype, args, kwds));
+    if (!newType)
+        return 0;
+    return reinterpret_cast<PyObject*>(newType);
+}
+
 } // extern "C"
 
 namespace Shiboken {
@@ -348,13 +382,12 @@ public:
     DeclaredEnumTypes();
     ~DeclaredEnumTypes();
     static DeclaredEnumTypes& instance();
-    void addEnumType(PyTypeObject* type, const char* cppName);
-    const char* getCppName(PyTypeObject* type);
+    void addEnumType(PyTypeObject* type);
 
 private:
     DeclaredEnumTypes(const DeclaredEnumTypes&);
     DeclaredEnumTypes& operator=(const DeclaredEnumTypes&);
-    std::map<PyTypeObject*, std::string> m_enumTypes;
+    std::list<PyTypeObject*> m_enumTypes;
 };
 
 namespace Enum {
@@ -383,11 +416,8 @@ PyObject* getEnumItemFromValue(PyTypeObject* enumType, long itemValue)
 static PyTypeObject* createEnum(const char* fullName, const char* cppName, const char* shortName, PyTypeObject* flagsType)
 {
     PyTypeObject* enumType = newTypeWithName(fullName, cppName);
-    if (flagsType) {
-        if (PyType_Ready(flagsType) < 0)
-            return 0;
+    if (flagsType)
         enumType->tp_as_number = flagsType->tp_as_number;
-    }
     if (PyType_Ready(enumType) < 0)
         return 0;
     Shiboken::TypeResolver::createValueTypeResolver<int>(cppName);
@@ -483,7 +513,6 @@ PyObject* newItem(PyTypeObject* enumType, long itemValue, const char* itemName)
     return reinterpret_cast<PyObject*>(enumObj);
 }
 
-
 PyTypeObject* newType(const char* name)
 {
     return newTypeWithName(name, "");
@@ -491,8 +520,8 @@ PyTypeObject* newType(const char* name)
 
 PyTypeObject* newTypeWithName(const char* name, const char* cppName)
 {
-    PyTypeObject* type = new PyTypeObject;
-    ::memset(type, 0, sizeof(PyTypeObject));
+    PyTypeObject* type = reinterpret_cast<PyTypeObject*>(new SbkEnumType);
+    ::memset(type, 0, sizeof(SbkEnumType));
     Py_TYPE(type) = &SbkEnumType_Type;
     type->tp_basicsize = sizeof(SbkEnumObject);
     type->tp_print = &SbkEnumObject_print;
@@ -506,20 +535,37 @@ PyTypeObject* newTypeWithName(const char* name, const char* cppName)
     type->tp_richcompare = &enum_richcompare;
     type->tp_hash = &enum_hash;
 
-    DeclaredEnumTypes::instance().addEnumType(type, cppName);
+    SbkEnumType* enumType = reinterpret_cast<SbkEnumType*>(type);
+    enumType->cppName = cppName;
+    enumType->converterPtr = &enumType->converter;
+    DeclaredEnumTypes::instance().addEnumType(type);
     return type;
 }
 
 const char* getCppName(PyTypeObject* enumType)
 {
-    return DeclaredEnumTypes::instance().getCppName(enumType);
+    assert(Py_TYPE(enumType) == &SbkEnumType_Type);
+    return reinterpret_cast<SbkEnumType*>(enumType)->cppName;;
 }
 
 long int getValue(PyObject* enumItem)
 {
+    assert(Shiboken::Enum::check(enumItem));
     return reinterpret_cast<SbkEnumObject*>(enumItem)->ob_value;
 }
 
+void setTypeConverter(PyTypeObject* enumType, SbkConverter* converter)
+{
+    //reinterpret_cast<SbkEnumType*>(enumType)->converter = converter;
+    SBK_CONVERTER(enumType) = converter;
+}
+
+SbkConverter* getTypeConverter(PyTypeObject* enumType)
+{
+    //return reinterpret_cast<SbkEnumType*>(enumType)->converter;
+    return SBK_CONVERTER(enumType);
+}
+
 } // namespace Enum
 
 DeclaredEnumTypes& DeclaredEnumTypes::instance()
@@ -534,24 +580,15 @@ DeclaredEnumTypes::DeclaredEnumTypes()
 
 DeclaredEnumTypes::~DeclaredEnumTypes()
 {
-    std::map<PyTypeObject*, std::string>::const_iterator it = m_enumTypes.begin();
+    std::list<PyTypeObject*>::const_iterator it = m_enumTypes.begin();
     for (; it != m_enumTypes.end(); ++it)
-        delete (*it).first;
+        delete *it;
     m_enumTypes.clear();
 }
 
-void DeclaredEnumTypes::addEnumType(PyTypeObject* type, const char* cppName)
+void DeclaredEnumTypes::addEnumType(PyTypeObject* type)
 {
-    m_enumTypes[type] = cppName;
-}
-
-const char* DeclaredEnumTypes::getCppName(PyTypeObject* type)
-{
-     std::map<PyTypeObject*, std::string>::const_iterator it = m_enumTypes.find(type);
-     if (it != m_enumTypes.end())
-         return it->second.c_str();
-     else
-         return "";
+    m_enumTypes.push_back(type);
 }
 
 }
